durationtools.Duration
======================

.. abjad-lineage:: abjad.tools.durationtools.Duration.Duration.Duration

.. autoclass:: abjad.tools.durationtools.Duration.Duration.Duration
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.denominator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.dot_count
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.equal_or_greater_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.equal_or_greater_power_of_two
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.equal_or_lesser_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.equal_or_lesser_power_of_two
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.flag_count
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.has_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.imag
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.is_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.lilypond_duration_string
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.numerator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.pair
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.prolation_string
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.real
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.reciprocal
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.conjugate
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.from_decimal
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.from_float
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.limit_denominator
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.with_denominator
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__abs__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__add__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__complex__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__div__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__divmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__eq__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__float__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__floordiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__ge__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__gt__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__hash__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__le__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__lt__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__mod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__mul__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__ne__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__neg__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__nonzero__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__pos__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__pow__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__radd__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rdiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rdivmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__repr__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rfloordiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rmul__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rpow__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rsub__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rtruediv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__str__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__sub__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__truediv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__trunc__
   :noindex:
